@@ -1,10 +1,13 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import os
 import tempfile
 
-__version__ = "0.1.13"
+try:
+    from importlib import metadata
+except ImportError:
+    # Running on pre-3.8 Python; use importlib-metadata package
+    import importlib_metadata as metadata
+
+__version__ = metadata.version("fake-useragent")
 
 DB = os.path.join(
     tempfile.gettempdir(),
